@@ -545,7 +545,7 @@ class S3Client {
         foreach ($parts as $part) {
             $xml .= '<Part>';
             $xml .= '<PartNumber>' . $part['PartNumber'] . '</PartNumber>';
-            $xml .= '<ETag>' . $part['ETag'] . '</ETag>';
+            $xml .= '<ETag>"' . $part['ETag'] . '"</ETag>';
             $xml .= '</Part>';
         }
         $xml .= '</CompleteMultipartUpload>';
